@@ -20,12 +20,6 @@ if [ -d /usr/X11R6/lib/X11/nls ]; then
     export XNLSPATH
 fi
 
-
-# Extret del Spanish-COMO
-set meta-flag on		# conservar bit 8 en l'entrada de teclat
-set output-meta on		# conservar bit 8 en la sortida per terminal
-set convert-meta off		# no convertir sequencies d'escapament
-set horizontal-scroll-mode on
 LESSCHARSET=latin1
 
 # Obtingut de http://members.xoom.com/sromero/linux/castell.html
