@@ -1,7 +1,7 @@
 ; s comment -*-coding: euc-kr;-*-
-Setting fot Sawfish WindowManager.
+Setting for Sawfish WindowManager.
 END
-Setting fot Sawfish WindowManager.
+Sawfish Ŵ .
 END
 print <<"EOF";
 (setq fonts-are-fontsets t)
