@@ -1,6 +1,6 @@
 # !Turkce,Turkish! -*-coding: iso-8859-9;-*-
 # Turkish support for language-env.
-# Copyright (C) 2004  Recai Oktas <roktas@omu.edu.tr>
+# Copyright (C) 2004  Recai Okta <roktas@omu.edu.tr>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -284,6 +284,7 @@ sub initialize()
 		# --------------------------------------------------
 		# Keyboard selection.
 		# --------------------------------------------------
+		# TODO: Add support for alt keyboard.
 		$c = &Sub::select(
 			"\nKlavye duzenini secin.\n" .
 			"1: Turkce Q klavye   2: Turkce F klavye\n",
@@ -291,13 +292,9 @@ sub initialize()
 			"1: Trke Q klavye   2: Trke F klavye\n", 2, 1);
 
 		if ($c == 1) {
-			$Sub::XKEYB = "basic"; $Sub::XKEYB_OPTS = "caps:shift";
-			$Sub::CKEYB = "trq"    if ($Sub::ENCODING eq "ISO-8859-9");
-			$Sub::CKEYB = "trqu"   if ($Sub::ENCODING eq "UTF-8");
+			$Sub::KTYPE = "q";
 		} elsif ($c == 2) {
-			$Sub::XKEYB = "tr_f";  $Sub::XKEYB_OPTS = "caps:shift";
-			$Sub::CKEYB = "trf"    if ($Sub::ENCODING eq "ISO-8859-9");
-			$Sub::CKEYB = "trfu"   if ($Sub::ENCODING eq "UTF-8");
+			$Sub::KTYPE = "f";
 		}
 	
 		# --------------------------------------------------
